==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/identitystore/kotlin/inputs/GetUserAlternateIdentifierUniqueAttribute.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.identitystore.kotlin.inputs

import com.pulumi.aws.identitystore.inputs.GetUserAlternateIdentifierUniqueAttribute.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property attributePath Attribute path that is used to specify which attribute name to search. For example: `UserName`. Refer to the [User data type](https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_User.html).
 * @property attributeValue Value for an attribute.
 */
public data class GetUserAlternateIdentifierUniqueAttribute(
    public val attributePath: String,
    public val attributeValue: String,
) : ConvertibleToJava<com.pulumi.aws.identitystore.inputs.GetUserAlternateIdentifierUniqueAttribute> {
    override fun toJava():
        com.pulumi.aws.identitystore.inputs.GetUserAlternateIdentifierUniqueAttribute =
        com.pulumi.aws.identitystore.inputs.GetUserAlternateIdentifierUniqueAttribute.builder()
            .attributePath(attributePath.let({ args0 -> args0 }))
            .attributeValue(attributeValue.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetUserAlternateIdentifierUniqueAttribute].
 */
@PulumiTagMarker
public class GetUserAlternateIdentifierUniqueAttributeBuilder internal constructor() {
    private var attributePath: String? = null

    private var attributeValue: String? = null

    /**
     * @param value Attribute path that is used to specify which attribute name to search. For example: `UserName`. Refer to the [User data type](https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_User.html).
     */
    @JvmName("bjtvkaokoaohhqvr")
    public suspend fun attributePath(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.attributePath = mapped
    }

    /**
     * @param value Value for an attribute.
     */
    @JvmName("pffbekyegpkdvshk")
    public suspend fun attributeValue(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.attributeValue = mapped
    }

    internal fun build(): GetUserAlternateIdentifierUniqueAttribute =
        GetUserAlternateIdentifierUniqueAttribute(
            attributePath = attributePath ?: throw PulumiNullFieldException("attributePath"),
            attributeValue = attributeValue ?: throw PulumiNullFieldException("attributeValue"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/identitystore/kotlin/inputs/GetUserAlternateIdentifierUniqueAttribute.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.identitystore.kotlin.inputs

import com.pulumi.aws.identitystore.inputs.GetUserAlternateIdentifierUniqueAttribute.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property attributePath Attribute path that is used to specify which attribute name to search. For example: `UserName`. Refer to the [User data type](https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_User.html).
 * @property attributeValue Value for an attribute.
 */
public data class GetUserAlternateIdentifierUniqueAttribute(
    public val attributePath: String,
    public val attributeValue: String,
) : ConvertibleToJava<com.pulumi.aws.identitystore.inputs.GetUserAlternateIdentifierUniqueAttribute> {
    override fun toJava(): com.pulumi.aws.identitystore.inputs.GetUserAlternateIdentifierUniqueAttribute =
        com.pulumi.aws.identitystore.inputs.GetUserAlternateIdentifierUniqueAttribute.builder()
            .attributePath(attributePath.let({ args0 -> args0 }))
            .attributeValue(attributeValue.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetUserAlternateIdentifierUniqueAttribute].
 */
@PulumiTagMarker
public class GetUserAlternateIdentifierUniqueAttributeBuilder internal constructor() {
    private var attributePath: String? = null

    private var attributeValue: String? = null

    /**
     * @param value Attribute path that is used to specify which attribute name to search. For example: `UserName`. Refer to the [User data type](https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_User.html).
     */
    @JvmName("cvcrwhgqliukyrvc")
    public suspend fun attributePath(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.attributePath = mapped
    }

    /**
     * @param value Value for an attribute.
     */
    @JvmName("rjbxyygqyvjcogkj")
    public suspend fun attributeValue(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.attributeValue = mapped
    }

    internal fun build(): GetUserAlternateIdentifierUniqueAttribute =
        GetUserAlternateIdentifierUniqueAttribute(
            attributePath = attributePath ?: throw PulumiNullFieldException("attributePath"),
            attributeValue = attributeValue ?: throw PulumiNullFieldException("attributeValue"),
        )
}
